@@ -1,4 +1,5 @@
 from functools import partial
+import inspect
 from graphene import Field, List
 from graphene.types.utils import get_type
 from graphene_django.filter.utils import (
@@ -19,6 +20,8 @@ class BalderFiltered(Field):
         _type,
         related_field=None,
         fields=None,
+        filter_fields=None,
+        model=None,
         extra_filter_meta=None,
         filterset_class=None,
         queryset_resolver=None,
@@ -35,9 +38,15 @@ class BalderFiltered(Field):
             filterset_class ([type], optional): [description]. Defaults to None.
             queryset_resolver ([type], optional): Function that resolves the initial queryset for the filter, is overwritten by related_field. Default to None
         """
-        _type = get_type(_type)
-        _fields = _type._meta.filter_fields
-        _model = _type._meta.model
+        if inspect.isfunction(_type) or isinstance(_type, partial):
+            assert (
+                model is not None
+            ), "If you provide a callable as a type please provide a model"
+            _fields = model._meta.filter_fields
+            _model = model
+        else:
+            _fields = _type._meta.model._meta.filter_fields
+            _model = _type._meta.model
 
         standard_resolver = (
             lambda root, info, *args, **kwargs: _model._default_manager.get_queryset()
