@@ -1,4 +1,6 @@
 from functools import partial
+import inspect
+from typing import Callable
 from graphene import Field, List
 import graphene
 from graphene.types.utils import get_type
@@ -20,6 +22,8 @@ class BalderFilteredWithOffset(Field):
         _type,
         related_field=None,
         fields=None,
+        model=None,
+        filter_fields=None,
         extra_filter_meta=None,
         filterset_class=None,
         queryset_resolver=None,
@@ -36,9 +40,16 @@ class BalderFilteredWithOffset(Field):
             filterset_class ([type], optional): [description]. Defaults to None.
             queryset_resolver ([type], optional): Function that resolves the initial queryset for the filter, is overwritten by related_field. Default to None
         """
-        _type = get_type(_type)
-        _fields = _type._meta.filter_fields
-        _model = _type._meta.model
+        if inspect.isfunction(_type) or isinstance(_type, partial):
+            assert (
+                model is not None
+            ), "If you provide a callable as a type please provide a model"
+            _fields = model._meta.filter_fields
+            _model = model
+        else:
+            _fields = _type._meta.model._meta.filter_fields
+            _model = _type._meta.model
+
         standard_resolver = (
             lambda root, info, *args, **kwargs: _model._default_manager.get_queryset()
         )
@@ -50,6 +61,7 @@ class BalderFilteredWithOffset(Field):
         meta = dict(model=_model, fields=self.fields)
         if extra_filter_meta:
             meta.update(extra_filter_meta)
+
         self.filterset_class = get_filterset_class(
             filterset_class, **meta
         )  # create one if there is no filtersetclass provided
